@@ -466,7 +466,7 @@ class WellCorrelation:
         """
         # Prepare a DataFrame version of the alignment, with wells as indices
         df_msa = pd.DataFrame(self._multi_sequence_alignment.to_dict())
-        df_msa.loc[:] = df_msa.values.astype(str)
+        df_msa.loc[:] = df_msa.astype(str)
         df_msa.columns = [
             protein.metadata["id"] for protein in self._multi_sequence_alignment
         ]
